OC.L10N.register(
    "bookmarks",
    {
    "Details" : "ព័ត៌មាន​លម្អិត",
    "Rename" : "ប្ដូរ​ឈ្មោះ",
    "Move" : "Move",
    "Delete" : "លុប",
    "New" : "ថ្មី",
    "New folder" : "ថត​ថ្មី",
    "Cancel" : "បោះបង់",
    "Import" : "នាំយកចូល",
    "Export" : "នាំចេញ",
    "Title" : "ចំណងជើង",
    "Link" : "Link",
    "Tags" : "ស្លាក",
    "Notes" : "កំណត់​ចំណាំ",
    "Owner" : "Owner",
    "Sharing" : "ការ​ចែក​រំលែក",
    "Share link" : "Share link",
    "Select" : "Select",
    "Folder" : "ថត",
    "Save" : "រក្សាទុក"
},
"nplurals=1; plural=0;");
